==> omijacz_timera-0.2.0-py2.py3-none-any.whl: omijacz_timera_prawojazdy/omijacz_timera.py <==
"""Uruchamia automatyzację slajdów na prawojazdy.com.pl
Usage: omijacz_timera [-h] [-v] [-v]
-h  pokaż pomoc (o taką!)
-v  wersja
-vv  wyświetlaj więcej tekstu (verbose)
"""

from __future__ import division, print_function, absolute_import

from docopt import docopt
import time
import datetime

import omijacz_timera as automator
import omijacz_timera as automator_api

__version__ = "0.1"
__author__ = "Jonatan Witoszek"
__copyright__ = "Jonatan Witoszek"
__license__ = "MIT"

def execute():
    strona = automator.Prawojazdy()
    # Logowanie i wybieranie kursu
    strona.zaloguj_sie()
    while not strona.zalogowano():
        continue
    print("Przejdź do nauki i wybierz kurs...")
    while not strona.kurs_wybrany():
        continue
    # Tworzenie klasy dla API
    cookies = strona.find_cookies()
    url = strona.get_url()
    ajax = automator_api.Prawojazdy_API(cookies, url)
    ajax_header = ajax.get_header()
    # Pętla zaliczania slajdów
    while not strona.check_if_ended():
        # Sprawdzenie czy nie pytanie TODO: Temporary fix
        if strona.check_if_not_question():
            strona.nastepna_strona()
            continue
        # Odczytywanie danych ze strony
        slide_numer = strona.find_slide_number()
        if slide_numer == "0":
            strona.nastepna_strona()
        # Tworzenie i przekazywanie zapytania AJAX
        content = ajax.get_content(slide_numer)
        if not ajax.send_request(content, ajax_header):
            print("Niepowodzenie zapytania. Próbuję jeszcze raz...")
            time.sleep(5)
            ajax.send_request(content, ajax_header)
            strona.browser.reload()
        time.sleep(2.5)
        # Przechodzenie do następnej strony
        strona.nastepna_strona()
    strona.zamknij_strone()

def main():
    args = docopt(__doc__)
    # Arguments handling
    if args['-v']:
        print("""omijacz-timera-prawojazdy wersja {version}
        Created by {author}
        Copyright Jonatan Witoszek - {year} {licence}""".format(
            version=__version__,
            author=__author__,
            year=datetime.datetime.now().year,
            licence=__license__
        ))
    VERBOSE = args['-vv'] or False #  Todo: Add verbose messages
    execute()

if __name__ == "__main__":
    main()

==> omijacz_timera-0.4.0-py2.py3-none-any.whl: omijacz_timera_prawojazdy/omijacz_timera.py <==
"""Uruchamia automatyzację slajdów na prawojazdy.com.pl
Usage: omijacz_timera [-h] [-v] [-v]
-h  pokaż pomoc (o taką!)
-v  wersja
-vv  wyświetlaj więcej tekstu (verbose)
"""

from __future__ import division, print_function, absolute_import

from docopt import docopt
import time
import datetime

import omijacz_timera as automator
import omijacz_timera as automator_api

__version__ = "0.1"
__author__ = "Jonatan Witoszek"
__copyright__ = "Jonatan Witoszek"
__license__ = "MIT"

def execute():
    strona = automator.Prawojazdy()
    # Logowanie i wybieranie kursu
    strona.zaloguj_sie()
    while not strona.zalogowano():
        continue
    print("Przejdź do nauki i wybierz kurs...")
    while not strona.kurs_wybrany():
        continue
    # Tworzenie klasy dla API
    cookies = strona.find_cookies()
    url = strona.get_url()
    ajax = automator_api.Prawojazdy_API(cookies, url)
    ajax_header = ajax.get_header()
    # Pętla zaliczania slajdów
    while not strona.check_if_ended():
        # Sprawdzenie czy nie pytanie TODO: Temporary fix
        if strona.check_if_not_question():
            strona.nastepna_strona()
            continue
        # Odczytywanie danych ze strony
        slide_numer = strona.find_slide_number()
        if slide_numer == "0":
            strona.nastepna_strona()
        # Tworzenie i przekazywanie zapytania AJAX
        content = ajax.get_content_request(slide_numer)
        if not ajax.send_request(content, ajax_header):
            print("Niepowodzenie zapytania. Próbuję jeszcze raz...")
            time.sleep(5)
            ajax.send_request(content, ajax_header)
            strona.browser.reload()
        time.sleep(2.5)
        # Przechodzenie do następnej strony
        strona.nastepna_strona()
    strona.zamknij_strone()

def main():
    args = docopt(__doc__)
    # Arguments handling
    if args['-v']:
        print("""omijacz-timera-prawojazdy wersja {version}
        Created by {author}
        Copyright Jonatan Witoszek - {year} {licence}""".format(
            version=__version__,
            author=__author__,
            year=datetime.datetime.now().year,
            licence=__license__
        ))
    VERBOSE = args['-vv'] or False #  Todo: Add verbose messages
    execute()

if __name__ == "__main__":
    main()
